#include <ros/ros.h>
#include <string>
#include <iostream>
// PCL specific includes
#include <sensor_msgs/PointCloud2.h>
#include <pcl/point_types.h>
#include <pcl_conversions/pcl_conversions.h>
#include <pcl/conversions.h>
#include <pcl/ModelCoefficients.h>
#include <pcl/io/pcd_io.h>
#include <pcl/filters/extract_indices.h>
#include <pcl/filters/voxel_grid.h>
#include <pcl/features/normal_3d.h>
#include <pcl/kdtree/kdtree.h>
#include <pcl/sample_consensus/method_types.h>
#include <pcl/sample_consensus/model_types.h>
#include <pcl/segmentation/sac_segmentation.h>
#include <pcl/segmentation/extract_clusters.h>
#include <pcl_ros/point_cloud.h>



typedef pcl::PointCloud<pcl::PointXYZ> CloudType;
ros::Publisher pub;

void cloud_cb (const sensor_msgs::PointCloud2ConstPtr& input)
{

  pcl::PCLPointCloud2 pcl_pc;
  pcl_conversions::toPCL(*input, pcl_pc);

  pcl::PointCloud<pcl::PointXYZ> cloud;
  pcl::PointCloud<pcl::PointXYZ> filter;

  sensor_msgs::PointCloud2 output;

  pcl::fromPCLPointCloud2(pcl_pc, cloud);

  filter.header = cloud.header;  
  for(size_t i = 0; i < cloud.points.size (); ++i){
	// the parameters 1.4 and 0.0 will be changed with the height of the Kinect
	if(cloud.points[i].y > -1.4 && cloud.points[i].y < 0.0){
		cloud.points[i].y = 0.0;
		filter.points.push_back(cloud.points[i]);
	}
  }

  /*create and save pcd file
  pcl::io::savePCDFileASCII ("test_pcd.pcd", cloud);*/

  pcl::toPCLPointCloud2(filter, pcl_pc);
  pcl_conversions::moveFromPCL(pcl_pc, output);

  pub.publish(output);

}

int
main (int argc, char** argv)
{
  // Initialize ROS
  ros::init (argc, argv, "pcl_detector");
  ros::NodeHandle nh;

  // Create a ROS subscriber for the input point cloud
  ros::Subscriber sub = nh.subscribe<sensor_msgs::PointCloud2>("/camera/depth/points", 1, cloud_cb);

  // Create a ROS publisher for the output point cloud
  pub = nh.advertise<sensor_msgs::PointCloud2>("output", 1);

  // Spin
  ros::spin ();
}

